# SSW555 TeamAJRY: GEDCOM CLI

This is a project for the SSW555 of Stevens Institute of Technology taught by geekiest professor Jim Rowland.

---
- **Team Member**:
  - Yinghui Cai(Benji)
  - Rahil Patel(Ray)
  - Aniruddha Pimple(John)
  - Jiahua Zhou(Javer)

- **User stories for sprint 1**:

|Story ID|Story Name|Owner|
|:---:|:---:|:---:|
|US01|Dates before current date|Javer|
|US02|Birth before marriage|Ray|
|US03|Birth before death|John|
|US05|Marriage before death|John|
|US06|Divorce before death|Benji|
|US11|No bigamy|Ray|
|US20|Aunts and uncles|Benji|
|US22|Unique IDs|Javer|

---

## 0. Table of Content

1. [Installation & PyPI](#1-installation--pypi)
2. [Test Strategy](#2-test-strategy)

## 1 Installation & PyPI

The version 1.0.0 of this application has been published on the [PyPI](https://pypi.org), you can find the package on PyPI through this [**link**](https://pypi.org/project/GEDCOM-Benji/), you can also install the package with `pip`:

```py
pip install gedcom-benji
```

## 2 Test Strategy 

- [ ] Create a GEDCOM file with **NO** fault.
- [ ] Modify the file copy and manually create some weired cases.
  - **one weired cases for each modified file**
  - (**to be discussed**)merge the modified files the same time merging the tested code
- [ ] Expecting the program can find these weired cases.
